from http import HTTPStatus
from pathlib import Path

from styloexport.utils import get_env_var

SE_PANDOC_API_BASE_URL = get_env_var("SE_PANDOC_API_BASE_URL")


def test_export_generique_all(app, client, context, httpx_mock, tmp_path):
    httpx_mock.add_response(
        url="https://stylo.huma-num.fr/graphql",
        content=(Path() / "tests" / "fixtures" / "Corpus.graphql").read_text(),
    )
    httpx_mock.add_response(
        url="https://stylo.huma-num.fr/graphql",
        content=(Path() / "tests" / "fixtures" / "How_to_Stylo.graphql").read_text(),
    )
    httpx_mock.add_response(
        url="https://avatars2.githubusercontent.com/u/16691667?s=200&v=4",
        content=(
            Path() / "tests" / "fixtures" / "7dc926ed4014a96a908e5fb21de52329"
        ).read_bytes(),
        headers={"content-type": "image/png"},
    )
    httpx_mock.add_response(
        url=(
            f"{SE_PANDOC_API_BASE_URL}convert/html/"
            "?name=test.html&with_toc=false&with_ascii=false&with_link_citations=false"
            "&with_nocite=false"
        ),
        content=(Path() / "tests" / "fixtures" / "How_to_Stylo.html").read_bytes(),
    )
    httpx_mock.add_response(
        url=(
            f"{SE_PANDOC_API_BASE_URL}convert/tex/?name=test.tex&with_toc=false"
            "&with_link_citations=false&with_nocite=false"
        ),
        content=(Path() / "tests" / "fixtures" / "How_to_Stylo.tex").read_bytes(),
    )
    httpx_mock.add_response(
        url=(
            f"{SE_PANDOC_API_BASE_URL}convert/pdf/?name=test.pdf&with_toc=false"
            "&with_link_citations=false&with_nocite=false"
        ),
        content=(Path() / "tests" / "fixtures" / "How_to_Stylo.pdf").read_bytes(),
    )
    httpx_mock.add_response(
        url=(
            f"{SE_PANDOC_API_BASE_URL}convert/docx/?name=test.docx&with_toc=false"
            "&with_link_citations=false&with_nocite=false"
        ),
        content=(Path() / "tests" / "fixtures" / "How_to_Stylo.docx").read_bytes(),
    )

    formats = (
        "formats=originals&formats=html-full&formats=tex-full&formats=pdf-full"
        "&formats=docx-full"
    )
    response = client.get(
        (
            "/these-memoire/these/export/stylo.huma-num.fr/"
            "673777c4b15a620011acd308/test/"
            f"?{formats}&bibliography_style=chicagomodified&version="
        )
    )

    assert response.status_code == HTTPStatus.OK
    formats = "docx-full-html-full-originals-pdf-full-tex-full"
    filename = (
        f"test-673777c4b15a620011acd308-{formats}-"
        "toc-0-ascii-0-link-citations-0-nocite-0.zip"
    )
    assert response.headers["Content-Disposition"] == f"attachment; filename={filename}"


def test_export_generique_html_full_only(app, client, context, httpx_mock, tmp_path):
    httpx_mock.add_response(
        url="https://stylo.huma-num.fr/graphql",
        content=(Path() / "tests" / "fixtures" / "Corpus.graphql").read_text(),
    )
    httpx_mock.add_response(
        url="https://stylo.huma-num.fr/graphql",
        content=(Path() / "tests" / "fixtures" / "How_to_Stylo.graphql").read_text(),
    )
    httpx_mock.add_response(
        url="https://avatars2.githubusercontent.com/u/16691667?s=200&v=4",
        content=(
            Path() / "tests" / "fixtures" / "7dc926ed4014a96a908e5fb21de52329"
        ).read_bytes(),
        headers={"content-type": "image/png"},
    )
    httpx_mock.add_response(
        url=(
            f"{SE_PANDOC_API_BASE_URL}convert/html/"
            "?name=test.html&with_toc=false&with_ascii=false"
            "&with_link_citations=false&with_nocite=false"
        ),
        content=(Path() / "tests" / "fixtures" / "How_to_Stylo.html").read_bytes(),
    )

    formats = "formats=html-full"
    response = client.get(
        (
            f"/these-memoire/these/export/stylo.huma-num.fr/"
            "673777c4b15a620011acd308/test/"
            f"?{formats}&bibliography_style=chicagomodified&version="
        )
    )

    assert response.status_code == HTTPStatus.OK
    filename = (
        "test-673777c4b15a620011acd308-"
        "html-full-toc-0-ascii-0-link-citations-0-nocite-0.zip"
    )
    assert response.headers["Content-Disposition"] == f"attachment; filename={filename}"


def test_export_unsupported_format(client, context, httpx_mock, tmp_path):
    httpx_mock.add_response(
        url="https://stylo.huma-num.fr/graphql",
        content=(Path() / "tests" / "fixtures" / "Corpus.graphql").read_text(),
    )
    httpx_mock.add_response(
        url="https://stylo.huma-num.fr/graphql",
        content=(Path() / "tests" / "fixtures" / "How_to_Stylo.graphql").read_text(),
    )
    httpx_mock.add_response(
        url="https://avatars2.githubusercontent.com/u/16691667?s=200&v=4",
        content=(
            Path() / "tests" / "fixtures" / "7dc926ed4014a96a908e5fb21de52329"
        ).read_bytes(),
    )

    response = client.get(
        (
            "/sens-public/corpus/export/stylo.huma-num.fr/673777c4b15a620011acd308/test/"
            "?formats=unsupported_format&version="
        )
    )

    assert response.status_code == HTTPStatus.OK
    assert context[0]["form"].errors == {"formats": ["Not a valid choice."]}
